==> haskell-glob-0.10.2-71-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-glob.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 Glob
version:              0.10.2
visibility:           public
id:                   Glob-0.10.2-3nVoBiOJijA9OiBj5S4ual
key:                  Glob-0.10.2-3nVoBiOJijA9OiBj5S4ual
license:              BSD-3-Clause
maintainer:           Matti Niemenmaa <matti.niemenmaa+glob@iki.fi>
author:               Matti Niemenmaa
stability:            provisional
homepage:             http://iki.fi/matti.niemenmaa/glob/
synopsis:             Globbing library
description:
    A library for globbing: matching patterns against file paths.

category:             System
abi:                  305fde63035669ea6b8912c88548650a
exposed:              True
exposed-modules:      System.FilePath.Glob System.FilePath.Glob.Primitive
hidden-modules:
    System.FilePath.Glob.Base System.FilePath.Glob.Directory
    System.FilePath.Glob.Match System.FilePath.Glob.Simplify
    System.FilePath.Glob.Utils

import-dirs:          /usr/lib/ghc-9.0.2/site-local/Glob-0.10.2
library-dirs:         /usr/lib/ghc-9.0.2/site-local/Glob-0.10.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-glob
hs-libraries:         HSGlob-0.10.2-3nVoBiOJijA9OiBj5S4ual
depends:
    base-4.15.1.0 containers-0.6.4.1 directory-1.3.6.2
    dlist-1.0-JalAZsGq1LOCqqdFHHEpoL filepath-1.4.2.1
    transformers-0.5.6.2
    transformers-compat-0.7.2-ZzSHjvD4flB2ChCq5TVbH

haddock-interfaces:   /usr/share/doc/haskell-glob/html/Glob.haddock
haddock-html:         /usr/share/doc/haskell-glob/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-glob-0.10.2-90-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-glob.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 Glob
version:              0.10.2
visibility:           public
id:                   Glob-0.10.2-IV3EMKztTxU6CHYEAa9DJ0
key:                  Glob-0.10.2-IV3EMKztTxU6CHYEAa9DJ0
license:              BSD-3-Clause
maintainer:           Matti Niemenmaa <matti.niemenmaa+glob@iki.fi>
author:               Matti Niemenmaa
stability:            provisional
homepage:             http://iki.fi/matti.niemenmaa/glob/
synopsis:             Globbing library
description:
    A library for globbing: matching patterns against file paths.

category:             System
abi:                  9101445cf3d968174ddc42506b5d6280
exposed:              True
exposed-modules:      System.FilePath.Glob System.FilePath.Glob.Primitive
hidden-modules:
    System.FilePath.Glob.Base System.FilePath.Glob.Directory
    System.FilePath.Glob.Match System.FilePath.Glob.Simplify
    System.FilePath.Glob.Utils

import-dirs:          /usr/lib/ghc-9.2.8/site-local/Glob-0.10.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/Glob-0.10.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-glob
hs-libraries:         HSGlob-0.10.2-IV3EMKztTxU6CHYEAa9DJ0
depends:
    base-4.16.4.0 containers-0.6.5.1 directory-1.3.6.2
    dlist-1.0-HCxoMn9TirQDgPCFxho7O filepath-1.4.2.2
    transformers-0.5.6.2
    transformers-compat-0.7.2-9ApmiRwA3hS7UuQpOomcS

haddock-interfaces:   /usr/share/doc/haskell-glob/html/Glob.haddock
haddock-html:         /usr/share/doc/haskell-glob/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
